import { useContext, useState, useMemo, useEffect } from "react";
import { Container, Paper } from "@mui/material";
import { SearchBar } from "../../../components/common/SearchBar";
import { Table } from "../../../components/common/Table";
import { APIProvider, useAPIMethod, usePagination } from "../../../hooks/API";
import { columns, apiOptions, apiContext } from "../../utils/common-data";
import { sbDisabledArg } from "../../utils/common-args";

export default {
  title: "Common/SearchBar"
};

function createRequest(query, pagination) {
  return {
    query: query,
    ...pagination
  };
}

const Harness = (args) => {
  const [query, setQuery] = useState("");

  const client = useContext(apiContext);
  const { pagination, setPagination } = usePagination({
    rowsPerPageOptions: [5, 10, 20, 50]
  });
  const requestParams = useMemo(
    () => createRequest(query, pagination),
    [query, pagination]
  );
  const { value, loading } = useAPIMethod({
    fcn: client?.apis.hosts.list_hosts,
    params: requestParams
  });

  useEffect(
    () => setPagination({ totalCount: value?.totalCount ?? 0 }),
    [setPagination, value?.totalCount]
  );

  return (
    <SearchBar
      search={setQuery}
      loading={loading}
    >
      <Table
        {...{
          ...args,
          rows: value?.hostList,
          onPage: setPagination,
          pagination
        }}
      />
    </SearchBar>
  );
};

export const Default = (args) => (
  <APIProvider
    context={apiContext}
    options={apiOptions}
  >
    <Container sx={{ display: "flex" }}>
      <Paper sx={{ display: "flex" }}>
        <Harness {...args} />
      </Paper>
    </Container>
  </APIProvider>
);
Default.args = {
  columns
};
Default.argTypes = {
  columns: sbDisabledArg,
  rowClassName: sbDisabledArg
};
